import unittest
from hdistill.pipeline.sanitizer import Sanitizer

class SanitizerTests(unittest.TestCase):

    def test_sanitizer_strips_whitespace_and_newlines(self):
        sanitizer = Sanitizer()
        actual_output = sanitizer.sanitize(input)
        self.assertEqual(expected_output, actual_output)


input = ['\n      1.\n      ', 'Frank Darabont (dir.), Tim Robbins, Morgan Freeman', 'The Shawshank Redemption', '\n        ', '(1994)', '\n    ']
expected_output = ['1.', 'Frank Darabont (dir.), Tim Robbins, Morgan Freeman', 'The Shawshank Redemption', '(1994)',]


from adapters.http_client import HttpClient
from pipeline.html_parser import HtmlParser
from pipeline.sanitizer import Sanitizer
from pipeline.transformer import Transformer
from hdistill import HDistill
import pprint
import argparse

class SplitArgs(argparse.Action):
    def __call__(self, parser, namespace, values, option_string=None):
        setattr(namespace, self.dest, values.split(','))

def main():
    args = parse_args()
    process(args)

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("url", help="the URL of a webpage")
    parser.add_argument("xpath", help="the XPath query to extract specific data from the source HTML")
    parser.add_argument("set_size", help="used to transform a list of parsed HTML data into sublists of the given set_size", type=int)
    parser.add_argument("keys", help="a comma separated list of keys used as labels for each element in a set", action=SplitArgs)
    return parser.parse_args()

def process(args):
    http_client = HttpClient()
    html_parser = HtmlParser()
    sanitizer = Sanitizer()
    transformer = Transformer(
        args.set_size,
        args.keys)
    hdistill = HDistill(http_client, html_parser, sanitizer, transformer)
    distilled = hdistill.distill(args.url, args.xpath)
    pp = pprint.PrettyPrinter(indent=4)
    pp.pprint(distilled)

if __name__ == "__main__":
    main()


import unittest
from hdistill.pipeline.html_parser import HtmlParser

class HtmlParserTests(unittest.TestCase):

    def test_parse_html_returns_expected_list(self):
        html_parser = HtmlParser()
        parsed = html_parser.parse_html(test_data, '//td[@class="titleColumn"]/text() | //td[@class="titleColumn"]//a/text() | //td[@class="titleColumn"]//a/@title | //td[@class="titleColumn"]//span[@class="secondaryInfo"]/text()')
        self.assertIn('Frank Darabont (dir.), Tim Robbins, Morgan Freeman', parsed)
        self.assertIn('The Shawshank Redemption', parsed)
        self.assertIn('(1994)', parsed)

test_data = """
<tr>
    <td class="posterColumn">

    <span name="rk" data-value="1"></span>
    <span name="ir" data-value="9.220075738292811"></span>
    <span name="us" data-value="7.791552E11"></span>
    <span name="nv" data-value="2416800"></span>
    <span name="ur" data-value="-1.7799242617071886"></span>
<a href="https://www.imdb.com/title/tt0111161/?pf_rd_m=A2FGELUUNOQJNL&amp;pf_rd_p=e31d89dd-322d-4646-8962-327b42fe94b1&amp;pf_rd_r=0YG0BZZFTS61TBHT80ND&amp;pf_rd_s=center-1&amp;pf_rd_t=15506&amp;pf_rd_i=top&amp;ref_=chttp_tt_1"> <img src="./IMDb Top 250 - IMDb_files/MV5BMDFkYTc0MGEtZmNhMC00ZDIzLWFmNTEtODM1ZmRlYWMwMWFmXkEyXkFqcGdeQXVyMTMxODk2OTU@._V1_UY67_CR0,0,45,67_AL_.jpg" width="45" height="67" alt="The Shawshank Redemption">
</a>    </td>
    <td class="titleColumn">
      1.
      <a href="https://www.imdb.com/title/tt0111161/?pf_rd_m=A2FGELUUNOQJNL&amp;pf_rd_p=e31d89dd-322d-4646-8962-327b42fe94b1&amp;pf_rd_r=0YG0BZZFTS61TBHT80ND&amp;pf_rd_s=center-1&amp;pf_rd_t=15506&amp;pf_rd_i=top&amp;ref_=chttp_tt_1" title="Frank Darabont (dir.), Tim Robbins, Morgan Freeman">The Shawshank Redemption</a>
        <span class="secondaryInfo">(1994)</span>
    </td>
    <td class="ratingColumn imdbRating">
            <strong title="9.2 based on 2,416,800 user ratings">9.2</strong>
    </td>
    <td class="ratingColumn">
    <div class="seen-widget seen-widget-tt0111161" data-titleid="tt0111161">
        <div class="boundary">
            <div class="popover">
"""



import unittest
from hdistill.pipeline.transformer import Transformer

class TransformerTests(unittest.TestCase):

    def test_sanitizer_strips_whitespace_and_newlines(self):
        transformer = Transformer(4, ['Rank', 'Key People', 'Title', 'Year Released'])
        actual_output = transformer.transform(input)
        self.assertEqual(expected_output, actual_output)

input = ['1.', 'Frank Darabont (dir.), Tim Robbins, Morgan Freeman', 'The Shawshank Redemption', '(1994)',]
expected_output = [
    {
        'Rank': '1.',
        'Key People': 'Frank Darabont (dir.), Tim Robbins, Morgan Freeman',
        'Title': 'The Shawshank Redemption',
        'Year Released': '(1994)'
    }
]